@@ -1,7 +1,7 @@
 """
 Type annotations for datasync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs/)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_datasync/type_defs/)
 
 Usage::
 
@@ -13,10 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Sequence, Union
+from typing import IO, Any, Dict, List, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     AgentStatusType,
@@ -68,6 +67,8 @@ __all__ = (
     "CreateLocationEfsResponseTypeDef",
     "CreateLocationFsxLustreRequestRequestTypeDef",
     "CreateLocationFsxLustreResponseTypeDef",
+    "CreateLocationFsxOpenZfsRequestRequestTypeDef",
+    "CreateLocationFsxOpenZfsResponseTypeDef",
     "CreateLocationFsxWindowsRequestRequestTypeDef",
     "CreateLocationFsxWindowsResponseTypeDef",
     "CreateLocationHdfsRequestRequestTypeDef",
@@ -91,6 +92,8 @@ __all__ = (
     "DescribeLocationEfsResponseTypeDef",
     "DescribeLocationFsxLustreRequestRequestTypeDef",
     "DescribeLocationFsxLustreResponseTypeDef",
+    "DescribeLocationFsxOpenZfsRequestRequestTypeDef",
+    "DescribeLocationFsxOpenZfsResponseTypeDef",
     "DescribeLocationFsxWindowsRequestRequestTypeDef",
     "DescribeLocationFsxWindowsResponseTypeDef",
     "DescribeLocationHdfsRequestRequestTypeDef",
@@ -109,6 +112,8 @@ __all__ = (
     "DescribeTaskResponseTypeDef",
     "Ec2ConfigTypeDef",
     "FilterRuleTypeDef",
+    "FsxProtocolNfsTypeDef",
+    "FsxProtocolTypeDef",
     "HdfsNameNodeTypeDef",
     "ListAgentsRequestListAgentsPaginateTypeDef",
     "ListAgentsRequestRequestTypeDef",
@@ -268,6 +273,39 @@ CreateLocationFsxLustreResponseTypeDef = TypedDict(
     },
 )
 
+_RequiredCreateLocationFsxOpenZfsRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateLocationFsxOpenZfsRequestRequestTypeDef",
+    {
+        "FsxFilesystemArn": str,
+        "Protocol": "FsxProtocolTypeDef",
+        "SecurityGroupArns": Sequence[str],
+    },
+)
+_OptionalCreateLocationFsxOpenZfsRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateLocationFsxOpenZfsRequestRequestTypeDef",
+    {
+        "Subdirectory": str,
+        "Tags": Sequence["TagListEntryTypeDef"],
+    },
+    total=False,
+)
+
+
+class CreateLocationFsxOpenZfsRequestRequestTypeDef(
+    _RequiredCreateLocationFsxOpenZfsRequestRequestTypeDef,
+    _OptionalCreateLocationFsxOpenZfsRequestRequestTypeDef,
+):
+    pass
+
+
+CreateLocationFsxOpenZfsResponseTypeDef = TypedDict(
+    "CreateLocationFsxOpenZfsResponseTypeDef",
+    {
+        "LocationArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 _RequiredCreateLocationFsxWindowsRequestRequestTypeDef = TypedDict(
     "_RequiredCreateLocationFsxWindowsRequestRequestTypeDef",
     {
@@ -321,8 +359,8 @@ _OptionalCreateLocationHdfsRequestRequestTypeDef = TypedDict(
         "QopConfiguration": "QopConfigurationTypeDef",
         "SimpleUser": str,
         "KerberosPrincipal": str,
-        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
-        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
+        "KerberosKeytab": Union[str, bytes, IO[Any], StreamingBody],
+        "KerberosKrb5Conf": Union[str, bytes, IO[Any], StreamingBody],
         "Tags": Sequence["TagListEntryTypeDef"],
     },
     total=False,
@@ -595,6 +633,25 @@ DescribeLocationFsxLustreResponseTypeDef = TypedDict(
     },
 )
 
+DescribeLocationFsxOpenZfsRequestRequestTypeDef = TypedDict(
+    "DescribeLocationFsxOpenZfsRequestRequestTypeDef",
+    {
+        "LocationArn": str,
+    },
+)
+
+DescribeLocationFsxOpenZfsResponseTypeDef = TypedDict(
+    "DescribeLocationFsxOpenZfsResponseTypeDef",
+    {
+        "LocationArn": str,
+        "LocationUri": str,
+        "SecurityGroupArns": List[str],
+        "Protocol": "FsxProtocolTypeDef",
+        "CreationTime": datetime,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeLocationFsxWindowsRequestRequestTypeDef = TypedDict(
     "DescribeLocationFsxWindowsRequestRequestTypeDef",
     {
@@ -795,6 +852,22 @@ FilterRuleTypeDef = TypedDict(
     total=False,
 )
 
+FsxProtocolNfsTypeDef = TypedDict(
+    "FsxProtocolNfsTypeDef",
+    {
+        "MountOptions": "NfsMountOptionsTypeDef",
+    },
+    total=False,
+)
+
+FsxProtocolTypeDef = TypedDict(
+    "FsxProtocolTypeDef",
+    {
+        "NFS": "FsxProtocolNfsTypeDef",
+    },
+    total=False,
+)
+
 HdfsNameNodeTypeDef = TypedDict(
     "HdfsNameNodeTypeDef",
     {
@@ -1234,8 +1307,8 @@ _OptionalUpdateLocationHdfsRequestRequestTypeDef = TypedDict(
         "AuthenticationType": HdfsAuthenticationTypeType,
         "SimpleUser": str,
         "KerberosPrincipal": str,
-        "KerberosKeytab": Union[bytes, IO[bytes], StreamingBody],
-        "KerberosKrb5Conf": Union[bytes, IO[bytes], StreamingBody],
+        "KerberosKeytab": Union[str, bytes, IO[Any], StreamingBody],
+        "KerberosKrb5Conf": Union[str, bytes, IO[Any], StreamingBody],
         "AgentArns": Sequence[str],
     },
     total=False,
